package
module
Version:
v0.0.0-...-ed32b93
Opens a new window with list of versions in this module.
Published: May 29, 2015
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
gcm
GCM client for golang
How to use
Gets library
$ go get github.com/mokelab-go/gcm
write!
package main
import (
"fmt"
gcm "github.com/mokelab-go/gcm/impl"
)
const (
api_key = "INPUT YOUR API_KEY"
reg_id = "INPUT YOUR REG_ID"
)
func main() {
client := gcm.NewClient()
data := map[string]interface{}{}
_, err := client.Send(api_key, data, reg_id)
if err != nil {
fmt.Errorf("Failed to send GCM message : %s", err)
}
}
Documentation
¶
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.